# NRPyS: Python language bindings for `nrps-rs` substrate specificity predictor

## License
NRPyS is an open source tool available under the GNU Affero General Public
License version 3.0 or greater. See the [`LICENSE.txt`](LICENSE.txt) file for
details.
